@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use base qw( Alien::Base );
 
-our $VERSION = '1.00';
+our $VERSION = '1.02_001';
 
 1;
 
@@ -12,30 +12,25 @@ __END__
 
 =head1 NAME
 
-Alien::gdal - Compile gdal
+Alien::gdal - Compile gdal, the Geographic Data Abstraction Library
 
 =head1 SYNOPSIS
 
-  use Alien::gdal;
+    use Alien::gdal;
 
+    use Env qw(@PATH);
+    unshift @PATH, Alien::gdal->bin_dir;
 
-=head1 ABSTRACT
-
-use Env qw(@PATH);
-unshift @PATH, Alien::gdal->bin_dir;
- 
-print Alien::gdal->dist_dir;
-
-#  example assumes @args exists already
-system (Alien::gdal->bin_dir, 'gdalwarp', @args);
+    print Alien::gdal->dist_dir;
 
+    #  example assumes @args exists already
+    system (Alien::gdal->bin_dir, 'gdalwarp', @args);
+    
 =head1 DESCRIPTION
 
 GDAL is the Geographic Data Abstraction Library.  See L<http://www.gdal.org>.
 
 
-=back
-
 =head1 REPORTING BUGS
 
 Please send any bugs, suggestions, or feature requests to
@@ -48,7 +43,9 @@ L<Geo::GDAL>
 =head1 AUTHORS
 
 Shawn Laffan, E<lt>shawnlaffan@gmail.comE<gt>
-Jason Mumbulla (did all the initial work - see github log for details)
+
+Jason Mumbulla (did all the initial work - see git log for details)
+
 Ari Jolma
 
 =head1 COPYRIGHT AND LICENSE
